function Chapter_10_Figure_13

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This matlab file reproduces simulation studies in the book:
% Systems Biology: Mathematical modeling and model analysis
% by A. Kremling
%
% It is related to Figure 13 in Chapter 10
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% --- parameters

stimulus = logspace(-1,2.2,50); 

y0 = [0 0 0 0];
y02 = [0 0 0 0];

time = 0:0.1:20;

p.k_1 = 1;
p.k2 =  100;
p.k_2 = 1; 
p.k3  = 100; 

p.K = 0.1;
p.R0 = 1;
p.ksynm = 10;
p.ksynp = 1;
p.D0 = 1;
p.KI = 20;

% --- calculation

figure(2);clf
for k = 1:length(stimulus),
  
  p.k1 = stimulus(k); 
  [t,y,t2,y2] = sys(y0,y02,time,p);     % simulation wild type


  sp = y(:,1);
  rp = y(:,2);
  mrna = y(:,3);
  prot = y(:,4);

  rp_ss(k) = rp(end);
  sp_ss(k) = sp(end);
  
  sp2 = y2(:,1);
  rp2 = y2(:,2);
  mrna2 = y2(:,3);
  prot2 = y2(:,4);
  rp2_ss(k) = rp2(end);
  sp2_ss(k) = sp2(end);
  
  subplot(121),plot(t,mrna2),title('mRNA'),hold on
  subplot(122),plot(t,prot2),title('Prot'),hold on  

  r1 =  p.k1.*(1-sp) - p.k_1*sp;
  r2 =  p.k2*sp.*(1-rp) - p.k_2*(1-sp).*rp;
  r3 =   p.k3*rp;
 
  
end


% --- plotting

figure(1), subplot (121)
plot(stimulus,sp_ss,'b-',stimulus,sp2_ss,'b--');title({'Signal response curve of the two-component-system: Sensor Sp';...
    'The dashed line results from two model variation in the rate of dephosphorylation r_3.'})
xlabel('Stimulus'),ylabel('Sensor S_p')
figure(1), subplot (122)
plot(stimulus,rp_ss,'b-',stimulus,rp2_ss,'b--');title({'Signal response curve of the two-component-system: Regulator Rp';...
    'The dashed line results from two model variation in the rate of dephosphorylation r_3.'})
xlabel('Stimulus'),ylabel('Regulator R_p')


%______________________________________________________

function [t,y,t2,y2]=sys(y0,y02,time,p);

options = odeset('RelTol',6e-4,'AbsTol',[6e-5],'Vectorized','on');


[t,y] = ode15s(@f,time,y0,options,p);
[t2,y2] = ode15s(@f2,time,y02,options,p);

%______________________________________________________

function out = f(t,y,p)

sp=y(1,:);
rp=y(2,:);
mrna = y(3,:);
prot = y(4,:);

r1 = p.k1*(1-sp) - p.k_1*sp;
r2 = p.k2*sp.*(1-rp) - p.k_2*(1-sp).*rp;
r3 = p.k3*rp;

r = -p.K/2+sqrt(p.K^2/4+rp*p.K);
psi = r./(p.K+r);
rmrna = p.ksynm*psi*p.D0;
rprot = p.ksynp*mrna;

out =[r1 - r2
      r2 - r3
      rmrna - 5*mrna
      rprot - 0.5*prot];

%______________________________________________________

function out = f2(t,y,p)

sp=y(1,:);
rp=y(2,:);
mrna = y(3,:);
prot = y(4,:);

r = -p.K/2+sqrt(p.K^2/4+rp*p.K);
psi = r./(p.K+r);
rmrna = p.ksynm*psi*p.D0;
rprot = p.ksynp*mrna;

r1 = p.k1*(1-sp) - p.k_1*sp;
%r1 = p.k1*(1-sp).*(p.KI./(p.KI+prot)) - p.k_1*sp;
r2 = p.k2*sp.*(1-rp) - p.k_2*(1-sp).*rp;
%r3 = p.k3*(1-sp).*rp;
r3 = p.k3*(1-sp).*rp.*(prot./(p.KI+prot));

out =[r1 - r2
      r2 - r3
      rmrna - 5*mrna
      rprot - 0.5*prot];
