function Chapter_10_Figure_6_and_7

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This matlab file reproduces simulation studies in the book:
% Systems Biology: Mathematical modeling and model analysis
% by A. Kremling
%
% It is related to Figure 6 and 7 in Chapter 10
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

close all;

% --- parameters

p.Kx=0.1;
p.Ky=0.5;
p.H=2;
p.By=0;
p.Bz=0;
p.az=1;
p.bz=1;
p.ay=1;
p.by=1;

% --- calculation and plotting. 

[T,C]=ode15s(@c,[0 10],[0 0 0],[],p);

% --- Figure 10.6 left
figure(1)
[t,V]=ode15s(@f1,[0 10],[0 0],[],p);
subplot(121),plot(t,V(:,1),t,V(:,2));
hold on
plot(T,C(:,3),'r');
xlabel('time'), ylabel('Z^k (red),Z(green), Y(blue)')
title('Simulation study of a coherent FFL with an AND conjunction')

% --- Figure 10.6 right

[t,V]=ode15s(@f2,[0 10],[0 0],[],p);
subplot(122),plot(t,V(:,1),t,V(:,2));
hold on
plot(T,C(:,3),'r');
xlabel('time'), ylabel('Z^k (red),Z(green), Y(blue)')
title('OR conjunction')

% --- Figure 10.7 left
figure(2)
[t,V]=ode15s(@f3,[0 10],[0 0],[],p);
subplot(121), plot(t,V(:,1),t,V(:,2));
hold on
plot(T,C(:,3),'r');
xlabel('time'), ylabel('Z^k (red),Z(green), Y(blue)')
title('Simulation of the AND conjunction of the incoherent FFL')

% --- Figure 10.7 rigth

[t,V]=ode15s(@f32,[0 10],[0 0],[],p);
subplot(122),plot(t,V(:,1),t,V(:,2));
hold on
plot(T,C(:,3),'r');
xlabel('time'), ylabel('Z^k (red),Z(green), Y(blue)')
title('level of the basal synthesis of Y is increased')

%%% Definition ordinary differential equations
                                                                               
                                                                           
    function[dC]=c(T,C,p)
     
    x=0;              %%% Signal
    if T<=5
      x=1;
    else
      x=0;
    end    
    f_1uC  = ((x/p.Kx).^p.H)./(1 + (x/p.Kx).^p.H);
    f_2uC =  (1)./(1 + (C(3)./p.Ky).^p.H);
    f_2u2C =  (1)./(1 + (1/p.Ky).^p.H);
    
   
    dC =[p.By + f_1uC - C(1)
    f_1uC.*f_2uC - C(2)
    f_1uC.*f_2u2C - C(3)];
    dC=dC(:);
    

 %_____________________________________________________________________   
    
  % coherent 'and'
    function [dV]=f1(t,V,p)
      
    x=0;             %%% Signal
    if t<=5
      x=1;
    else
      x=0;
    end    
        
   dV(1)=p.By - p.ay*V(1) + p.by*(x./p.Kx).^p.H/(1+(x./p.Kx).^p.H); 
   dV(2)= p.Bz - p.az*V(2) + p.bz*(x./p.Kx).^p.H/(1+(x./p.Kx).^p.H)*(V(1)./p.Ky).^p.H/(1+(V(1)./p.Ky).^p.H);
     
    dV=dV(:);
            
             
%_____________________________________________________________________   
 
% coherent 'or'
 
 function [dV]=f2(t,V,p)
     
 x=0;
 if t<=5
   x=1;
 else
   x=0;
end    
        
   dV(1)= p.By - p.ay*V(1) + p.by* (x/p.Kx)^p.H/(1+(x/p.Kx).^p.H);
   dV(2)=p.Bz - p.az*V(2) + p.bz*(((x/p.Kx)^p.H/(1+(x/p.Kx).^p.H+(V(1)/p.Ky).^p.H))+((V(1)/p.Ky).^p.H/(1+(x/p.Kx).^p.H+(V(1)/p.Ky).^p.H)));
    
    dV=dV(:);

 
%_____________________________________________________________________   
 
    
 % incoherent 'and'
 
function [dV]=f3(t,V,p)
    
x=0;
if t<=5
  x=1.0;
else
  x=0;
end    
        
dV(1)=p.By - p.ay*V(1) + p.by* (x/p.Kx)^p.H/(1+(x/p.Kx).^p.H);
dV(2)=p.Bz-p.az*V(2)+p.bz*(x/p.Kx).^p.H/(1+(x/p.Kx).^p.H)*1/(1+(V(1)/p.Ky)^p.H); 

dV=dV(:);

 
%_____________________________________________________________________   
 
    
 % incoherent 'and'
 
function [dV]=f32(t,V,p)
    
p.By=0.5;  % basal synthesis level of Y  
    
x=0;
if t<=5
  x=1.0;
else
  x=0;
end    
        
dV(1)=p.By - p.ay*V(1) + p.by* (x/p.Kx)^p.H/(1+(x/p.Kx).^p.H);
dV(2)=p.Bz-p.az*V(2)+p.bz*(x/p.Kx).^p.H/(1+(x/p.Kx).^p.H)*1/(1+(V(1)/p.Ky)^p.H); 

dV=dV(:);
    
  
%_____________________________________________________________________   
 
  % incoherent 'or'
  
  function [dV]=f4(t,V,p)
      
        x=0;
    if t<=5
     x=1;
 else
     x=0;
    end    
f_1u  = ((x/p.Kx).^p.H)./(1 + (x/p.Kx).^p.H);
f_2u =  (1)./(1 + (V(1)./p.Ky).^p.H);
f_2u2 =  (1)./(1 + (1/p.Ky).^p.H);
        
 dV(1)=p.By + f_1u - V(1);
 dV(2)=p.Bz+f_1u.*f_2u - V(2);
    
 dV=dV(:);
    
   