function Chapter_11_Figure_8_and_9

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This matlab file reproduces simulation studies in the book:
% Systems Biology: Mathematical modeling and model analysis
% by A. Kremling
%
% It is related to Figure 8 and 9 in Chapter 11
%
% Note: Part of this .m file was taken from Matlab Exchange server
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

close all;

disp(' ')
disp(' NOTE: Here a MILP solver from Thomas Tr�tscher found')
disp('        on MATLAB central exchange is used!')
disp(' ')
disp(' ')

% stochiometrie of the network given in the text (See Figure 11.8)
% r2 to r7 are unknown, r1 is the measured input

% r   2   3   4   5   6   7 
N = [-1   0   0  -1   0   0 
      1  -1  -1   0   0   0 
      1  -1   0   0  -1   0 
      0   0   0   1  -1  -1];

[nN,qN] = size(N);

% objectiv function for inner problem (max X)

c1 = [1 1 0 2 1 0];   

% given input fluxes

%     -r1 is measured
b1 =  [-1
       0
       0
       0]; 

% objectiv function for outer problem (max P)

c2 = [0 0 2 0 1 0];

mut = 2; % max. number of mutations

flag = 2; % is used to switch between two possibilities
          % flag == 1 -> number of mutations is 'mut'
          % otherwiese -> number of mutations is less or equal 'mut' 

% preparation of all matrices and solution

[x_best,val] = mip_problem(N,b1,c1,c2,mut,flag);  

disp(' ')
disp(' ')
disp(' ____________________________________')
disp(' ')
disp(' Results: ')
disp(' ')

disp('flux map (rates r2 - r7)')

disp(x_best(1:qN));

disp('enzymes (on or off)')

disp(x_best(qN+nN+1:qN+nN+qN));

disp('inner obj')

disp(c1*x_best(1:qN));

disp('outer obj')

disp(-val);

disp(' ')
disp(' ____________________________________')
disp(' ')
disp('comparison with only linear prog**')

disp('flux map ** (rates r2 - r7)')

opp = optimset('Display','off');
[x1] = linprog(-c1,[],[],N,b1,zeros(qN,1),10*ones(qN,1),[],opp);
disp(x1)

disp('inner obj **')

disp(c1*x1);

disp('outer obj **')

disp(c2*x1);


%___________________________________________________________________________
%___________________________________________________________________________


function [x_best,objective] = mip_problem(N,b1,c1,c2,mut,flag);
%
%  N == stoch
%  b == measured rates
%  c1 == inner objective
%  c2 == outer objective


[nN,qN] = size(N);

% set Aeq

Z1 = zeros(nN,nN);
Z2 = zeros(nN,qN);
z = zeros(1,qN);
z2 = zeros(1,nN);

if flag == 1,     % number mutation must

  Aeq = [N Z1 Z2 
	 c1 -b1' z
	 z  z2 -ones(1,qN)];

  beq =  [b1;0;-qN+mut];     

else             % number mutation upper limit
  
   Aeq = [N Z1 Z2 
	 c1 -b1' z
	 ];

  beq =  [b1;0];

end


%  set A

I1 = eye(qN);
lb= zeros(qN,1);
Lb = diag(lb);

ubmax = 3;
ub = ubmax*ones(qN,1);
Ub = diag(ub);

Z3 = zeros(qN,nN);
Z4 = zeros(qN,qN);

if flag == 1,

  A = [-I1 Z3 Lb
       I1 Z3 -Ub
       Z4 -N' Z4];
  
  b = [z'
       z'
       -c1'];

else

  A = [-I1 Z3 Lb
       I1 Z3 -Ub
       Z4 -N' Z4
       z z2 -ones(1,qN)];
  
  b = [z'
       z'
       -c1'
      -qN+mut];

end

% objectiv function for outer problem

c_f = -[c2 z2 z];

lb_f = [z -10*ones(1,nN) z]';
ub_f = [ub' ub(1)*ones(1,nN) ones(1,qN)]';
yidx = [false(qN+nN,1);true(qN,1)];
[x_best,objective] = miprog(c_f,A,b,Aeq,beq,lb_f,ub_f,yidx);


%___________________________________________________________________

function [x_best,f_best] = miprog(c,A,b,Aeq,beq,lb,ub,yidx,o)
%MIPROG
% Branch and bound algorithm for linear mixed integer programs
% x_best = miprog(c,A,b,Aeq,beq,lb,ub,yidx,[options])
%
%   min c'*x s.t. A*x <= b Aeq*x == beq lb <= x <= ub x(yidx) in [0,1,2,...]
% 
%   where yidx is a logical index vector such that
%   x(yidx) are the integer variables
% 
% Input:
% c,A,b,Aeq,beq,lb,ub - problem matrices
% yidx - a logical index vector such that y = x(yidx)
% options - (optional) mipoptions 
% 
% Output:
% x_best - best integer solution found
% 
% See Also:
% mip_gridoptim, gridoptions
% 
% Programmed by Thomas Tr�tscher 2009
%  

tic;
if nargin<9
    o = mipoptions();
end

if nargin<8
    error('MIPROG: Too few input arguments')
end

if ~islogical(yidx) || sum(yidx)<1 || length(c) ~= length(yidx)
    error('MIPROG: yidx must be a logical vector the size of x with at least one true element')
end

%% Init
%add upper and lower bounds to A
Ab = speye(length(yidx));
if ~isempty(lb)
    A = [A; -Ab];
    b = [b; -lb];
end
if ~isempty(ub)
    A = [A; Ab];
    b = [b; ub];
end
%delete all-zero rows
b = b(any(A,2),:);
A = A(any(A,2),:);

%Which lp solver are we using? Do som initializing...
if strcmp(o.solver,'bp')
    e = [zeros(size(Aeq,1),1); -ones(size(A,1),1)];
    A = [Aeq;A];
    b = [beq;b];
    opts=[];
    sol=1;
elseif strcmp(o.solver,'linprog')
    e=[];
    opts = optimset('Display','off');
    sol=2;
elseif strcmp(o.solver,'clp')
    e=[];
    opts=[];
    sol=3;
elseif strcmp(o.solver,'qsopt')
    e=[];
    opts=[];
    sol=5;
else
    error('MIPROG: Wrong lp solver')
end

%Assume no initial best integer solution
%Add your own heuristic here to find a good incumbent solution, store it in
%f_best,y_best,x_best
f_best = inf;
y_best = [];
x_best = [];

%Variable for holding the objective function variables of the lp-relaxation
%problems
f = inf(o.maxNodes,1);
f(1) = 0;
fs = inf;
numIntSol = double(~isempty(y_best));

%Set of problems
S = nan(sum(yidx),1);
D = zeros(sum(yidx),1);

%The priority in which the problems shall be solved
priority = [1];
%The indices of the problems that have been visited
visited = nan(o.maxNodes,1);

%Plot each iteration?
i=0;
if o.iterplot
    figure;
    hold on;
    title('Bounds')
    xlabel('Iteration')
    ylabel('Obj. fun. val')
end
%% Branch and bound loop
while i==0 || isinf(f_best) || (~isempty(priority) &&  ((f_best-min(fs(priority)))/abs(f_best+min(fs(priority))) > o.Delta) &&  i<o.maxNodes)
    %Is the parent node less expensive than the current best
    if i==0 || fs(priority(1))<f_best
        %Solve the LP-relaxation problem
        i=i+1;
        s = S(:,priority(1));
        d = D(:,priority(1));
        [x,this_f,flag] = lpr(c,A,b,Aeq,beq,e,s,d,yidx,sol,opts);

        %Visit this node
        visited(i) = priority(1);
        priority(1) = [];
        if flag==-2 || flag==-5
            %infeasible, dont branch
            if i==1
                error('MIPROG: Infeasible initial LP problem. Try another LP solver.')
            end
            f(i) = inf;
        elseif flag==1
            %convergence
            f(i) = this_f;  
            if this_f<f_best
                y = x(yidx);
                %fractional part of the integer variables -> diff
                diff = abs(round(y)-y);
                if all(diff<o.intTol)
                    %all fractions less than the integer tolerance
                    %we have integer solution
                    numIntSol = numIntSol+1;
                    f_best = this_f;
                    y_best = round(x(yidx));
                    x_best = x;
                else
                    if o.branchCriteria==1
                        %branch on the most fractional variable
                        [maxdiff,branch_idx] = max(diff,[],1);
                    elseif o.branchCriteria==2
                        %branch on the least fractional variable
                        diff(diff<o.intTol)=inf;
                        [mindiff,branch_idx] = min(diff,[],1);
                    elseif o.branchCriteria==3
                        %branch on the variable with highest cost
                        cy = c(yidx);
                        cy(diff<o.intTol)=-inf;
                        [maxcost,branch_idx] = max(cy,[],1);
                    elseif o.branchCriteria==4
                        %branch on the variable with lowest cost
                        cy = c(yidx);
                        cy(diff<o.intTol)=inf;
                        [mincost,branch_idx] = min(cy,[],1);  
                    else
                        error('MIPROG: Unknown branch criteria.')
                    end
                    %Branch into two subproblems
                    s1 = s;
                    s2 = s;
                    d1 = d;
                    d2 = d;
                    s1(branch_idx)=ceil(y(branch_idx));
                    d1(branch_idx)=-1; %direction of bound is GE
                    s2(branch_idx)=floor(y(branch_idx));
                    d2(branch_idx)=1; %direction of bound is LE
                    nsold = size(S,2);
                    
                    % add subproblems to the problem tree
                    S = [S s1 s2];
                    D = [D d1 d2];
                    fs = [fs f(i) f(i)];
                    
                    nsnew = nsold+2;

                    if o.branchMethod==1 || (o.branchMethod==13 && numIntSol<6)
                        %depth first, add newly branched problems to the
                        %beginning of the queue
                        priority = [nsold+1:nsnew priority];
                    elseif o.branchMethod==2
                        %breadth first, add newly branched problems to the
                        %end of the queue
                        priority = [priority nsold+1:nsnew];
                    elseif o.branchMethod==3 || (o.branchMethod==13 && numIntSol>=6)
                        %branch on the best lp solution
                        priority = [nsold+1:nsnew priority];
                        [dum,pidx] = sort(fs(priority));
                        priority=priority(pidx);
                    elseif o.branchMethod==4
                        %branch on the worst lp solution
                        priority = [nsold+1:nsnew priority];
                        [dum,pidx] = sort(-fs(priority));
                        priority=priority(pidx);
                    else
                        error('MIPROG: Unknown branch method.')
                    end     
                end
            end
            if (strcmp(o.display,'improve') || strcmp(o.display,'iter')) && (f(i)==f_best || i==1) 
                disp(['It. ',num2str(i),'. Best integer solution: ',num2str(f_best),' Delta ',num2str(max([100*(f_best-min(fs(priority)))/abs(f_best+min(fs(priority))) 0 100*isinf(f_best)])),'%']);
                %disp(['Queue: ', num2str(length(priority))]);
            end
        else
            error('MIPROG: Problem neither infeasible nor solved, try another solver or reformulate problem!')
        end
        if strcmp(o.display,'iter')
            disp(['It. ',num2str(i),'. F-val(It): ',num2str(f(i)),' Delta ',num2str(max([100*(f_best-min(fs(priority)))/abs(f_best+min(fs(priority))) 0 100*isinf(f_best)])),'%. Queue len. ', num2str(length(priority))]);
        end
        if o.iterplot
            plot(i,[f_best min(fs(priority))],'x')
            if i==1
                legend('MIP','LP')
            end
            drawnow;
        end
    else %parent node is more expensive than current f-best -> don't evaluate this node
        priority(1) = [];
    end
end

if ~strcmp(o.display,'off')
    disp(['Iteration ', num2str(sum(~isnan(visited))), '. Optimization ended.']);
    if isempty(priority) || f_best<min(fs(priority))
        disp('Found optimal solution!')
    elseif ~isinf(f_best)
        disp(['Ended optimization. Current delta ',num2str(max([100*(f_best-min(fs(priority)))/f_best 0 100*isinf(f_best)])),'%']);
    else
        disp(['Did not find any integer solutions']);
    end
    disp(['Time spent ', num2str(toc), ' seconds']);
    disp(['Objective function value: ',num2str(f_best)]);
end



%____________________________________________________________________


function [x,fval,flag] = lpr(c,A,b,Aeq,beq,e,s,d,yidx,sol,opts)
%LPR
% Function to solve the lp-relaxation problem. Used by branch and bound
% algorithm.
% [x,fval,flag] = lpr(c,A,b,Aeq,beq,e,s,d,yidx,sol,opts)
%
% See Also:
% miprog
%
% Thomas Tr�tscher 2009
%

%Calculate the extra constraints imposed by s
%if s is all NaN then no new constraints
sidx = ~isnan(s);
ydiag = double(yidx);
if any(sidx)
    ydiag(yidx) = d;
    l = length(yidx);  
    Y = spdiags(ydiag,0,l,l);
    %Remove zero entries
    Y = Y(any(Y,2),:);
end
if sol==1
    %BP
    if any(sidx)
        A = [A; Y];
        b = [b; s(sidx)];
        e = [e; zeros(sum(sidx),1)];
    end
    [x,y,s,w,how] = bp([],A,b,c,e,[],[],[],[],opts);
    fval = c'*x;
    if strcmp(how,'optimal solution')
        flag = 1;
    elseif strcmp(how,'infeasible dual')
        flag = -5;
    elseif strcmp(how,'infeasible primal')
        flag = -2;
    else
        warning(['BP: ',how])
        flag = -7;
    end
elseif sol==2
    %linprog
    if any(sidx)
        A = [A; Y];
        b = [b; s(sidx).*d(sidx)];
    end
    [x,fval,flag] = linprog(c,A,b,Aeq,beq,[],[],[],opts);
elseif sol==3
    %CLP
    if any(sidx)
        A = [A; Y];
        b = [b; s(sidx).*d(sidx)];
    end
    %[x,lambda,status,fval] = clp([],c,A,b,Aeq,beq,-inf(size(A,2),1),inf(size(A,2),1),opts,-inf(size(b,1),1));
    [x,lambda,status] = clp([],c,A,b,Aeq,beq,[],[],opts);
    fval = c'*x;
    if status==0
        flag=1; %converged
    elseif status==1
        flag=-2; %infeasible
    else
        warning('CLP: unbounded')
        flag=-3; %unbounded
    end
elseif sol==5
    %QSopt
    if any(sidx)
        A = [A; Y];
        b = [b; s(sidx).*d(sidx)];
    end
    [x,z,status] = qsopt(c,A,b,Aeq,beq,[],[],opts);
    fval = c'*x;
    if status==1
        flag=1; %converged
    elseif status==2
        flag=-2; %infeasible
    elseif status==3
        flag=-3; %unbounded
    else
        %time/iter/other
        warning(['QSOPT: ',num2str(status)])
        flag=-7;
    end
end

function o = mipoptions()
%MIPOPTIONS
% Returns default options struct for miprogram
% options = mipoptions()
%
% The default values are shown first, then an explanation and optional
% values.
%
% options.display = 'iter';
% Algorithm display [iter,improve,final,off]
%
% options.iterplot = false;
% Plot upper and lower bounds on objective function value while iterating
% [true,false]
%
% options.solver = 'linprog';
% LP solver (the user must make sure the lp solver is on the matlab path)
% It is highly recommended NOT to use linprog which comes with MATLAB
% [bp,linprog,clp,qsopt]
%
% options.Delta = 1e-8;
% Stopping tolerance of the gap (f_integer-f_lp)/(f_integer+f_lp)
%
% options.maxNodes = 1e5;
% Maximum number of nodes in the branch and bound tree to visit
%
% options.branchMethod = 3;
% 1 - depth first, 2 - breadth first, 3 - lowest cost, 4 - highest cost
%
% options.branchCriteria = 1; 
% 1 - most fractional, 2 - least fractional, 3 - highest cost, 4 - lowest cost
%
% options.intTol = 1e-6;
% Integer tolerance
%
%                 
% See Also:
% miprog
%
% Thomas Tr�tscher 2009
%

%Algorithm display (iter,improve,final,off)
o.display = 'iter';

%Plot upper and lower bounds on objective function value while iterating
o.iterplot = false;

%LP solver (the user must make sure the lp solver is on the matlab path)
% It is highly recommended NOT to use linprog which comes with MATLAB
% Mex interfaces for the other solvers are available online - just google it
% [bp,linprog,clp,qsopt]
o.solver = 'linprog';
%o.solver = 'bp';

%Branch and bound specific options
o.Delta = 1e-8; %Stopping tolerance of the gap (f_integer-f_lp)/(f_integer+f_lp)
o.maxNodes = 1e5; %Maximum number of nodes in the branch and bound tree to visit
o.branchMethod = 3; %1 - depth first, 2 - breadth first, 3 - lowest cost, 4 - highest cost
o.branchCriteria = 1; %1 - most fractional, 2 - least fractional, 3 - highest cost, 4 - lowest cost
o.intTol = 1e-6; %Integer tolerance