function Chapter_3_Figure_10

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This matlab file reproduces simulation studies in the book:
% Systems Biology: Mathematical modeling and model analysis
% by A. Kremling
%
% It is related to Figure 10 in Chapter 3
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% --- parameters

V = 2e-15;                  % volumen
N = [-1  1 0 0 0            % stoichiometry
      1 -1 0 0 0
      0  0 1 -1 1];

L = (abs(N)-N)/2;           % regulation
L(2,3) = 1;
L(3,1) = 2;

n0 = [2;1;100];             % AB
tmax = 1000;                % t maximum
c(1) = 1e-4/6;              % c - values
c(2) = 1;
c(3) = 3.5;
c(4) = 0.01;
c(5) = 0.2;
c=c';
max_cell = 1000;            % number of cells
pMax = 1200;                % maximum number of  protein molecules
mMax = n0(1)+n0(2);         % maximum number promotor molecules
fig_nr=1;                   % figure for output


NaV = 6.022e23*V;
K = sum(L)';
p.k = c.*((NaV).^(K-1))./(prod(factorial(L))');
p.N = N;
p.L = L;
p.d0 = (n0(1)+n0(2))/NaV;

% --- calculation: rates r3 and r4.
p_l = 0:0.01e-6:1e-6;
uu = p.k(3)*p.d0;
r3=NaV*(p.k(5)+uu*(p_l.^2./(p_l.^2. + p.k(2)/p.k(1))));
r4=NaV*p.k(4)*p_l;

% --- plotting:rates r3(Pr) and r4(Pr).
figure(1);subplot(121)
plot(p_l*NaV,r3,'k',p_l*NaV,r4) 
axis([0 1200 0 12]), grid, xlabel('protein particles'), ylabel('rates')
legend('r_3(Pr)','r_4(Pr)')
title({'Plotting of the rates r_3(Pr) and r_4(Pr) as a function of Pr.';...
    'The number of intersections represents the number of equilibrium states'})

%_________________________________________________

% --- calculation: Figure 3.10 right. 

% Deterministic Simulation 

NaV = 6.022e23*V;
figure(1);

% calculation for different start values

for i=1:6
k=[0.1; 0.5; 1; 1.1; 1.5; 2];                   %for calculation of different start values for Pr. 
n0 = [2;1;100*k(i)];                            % start values      
[tt,y] = sim_dyn_gen_work(N,L,c,tmax,n0,V);
dz = y(:,1)*NaV;
do = y(:,2)*NaV;
prot = y(:,3)*NaV;

% --- plotting
subplot(122)
plot(tt,prot)
xlabel('time [min]'), ylabel('particles')
title('Simulation study for different start values for Pr.')
hold on
end

%_____________________________________________________________
%  functions
%_____________________________________________________________
%_____________________________________________________________
% deterministic System

function [t,y] = sim_dyn_gen_work(N,L,c,tmax,y00,V)

NaV = 6.022e23*V;
K = sum(L)';
p.k = c.*((NaV).^(K-1))./(prod(factorial(L))');
p.N = N;
p.L = L;
y0 = y00/NaV;
time = 0:tmax/1000:tmax;

options = odeset('RelTol',1e-6,'AbsTol',1e-9,'Vectorized','on');
[t,y] = ode15s(@f,time,y0,options,p);

% ----------------------------------------------------------

function out = f(t,y,p)

p.N = p.N(:,1:4);
r1 = p.k(1)*y(1,:).*y(3,:).^2;
r2 = p.k(2)*y(2,:);
r3 = p.k(5)*ones(1,length(y(2,:)))+p.k(3)*y(2,:);
r4 = p.k(4)*y(3,:);
rr = [r1;r2;r3;r4];

out = p.N*rr;


