function Chapter_3_Figure_3_Figure_4
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This matlab file reproduces simulation studies in the book:
% Systems Biology: Mathematical modeling and model analysis
% by A. Kremling
%
% It is related to Figure 3 and Figure 4 in Chapter 3
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% --- parameters
nn = 1000;          % max number of molecules that is simulated
y0 = zeros(nn,1);  
time = 0:0.05:5;    % max time = 5
y0(21) = 1;         % case 1: for t=0 we have 20 molecules
%y0(2) = 1;         % case 2: for t=0 we have 1 molecule

% --- calculation
options = odeset('RelTol',1e-6,'AbsTol',[1e-9],'Vectorized','on');
[t,y] = ode15s(@f,time,y0,options,nn);
ly = length(y0);
XX = zeros(length(t),1);
for l = 1:ly,
  XX = XX+(l-1)*y(:,l);
end

% --- plotting: Figure 3.3

figure(1);subplot (121);
plot(t,XX,t,20*exp(-t),'r')             % compares mean value with deterministic simulation
                                        % for case 1
%plot(t,XX,t,exp(t),'r')                % for case 2
title('Comparison mean value with deterministic simulation'), xlabel('time'), ylabel('n');
figure(1); subplot (122);
plot(t,[y(:,1) y(:,6) y(:,16) y(:,21)])
title('Temporal trend of the probabilities P_n(t) '), xlabel('time'), ylabel('P_n');
legend('n=0', 'n=5', 'n=15', 'n=20')

% --- plotting: Figure 3.4
figure(2);subplot (131); bar(0:20,y(11,1:21))         % distribution for t = 0,5  
title('Distribution for t=0,5'), xlabel('n'), ylabel('P(t=0,5)');
figure(2);subplot (132);bar(0:20,y(31,1:21))          % distribution for t = 2 
title('Distribution for t=2'), xlabel('n'), ylabel('P(t=2)')
figure(2);subplot (133);bar(0:20,y(51,1:21))          % distribution for t = 2,5  
title('Distribution for t=2,5'), xlabel('n'), ylabel('P(t=2,5)')

% ----------------------------------------------------------

function out = f(t,y,nn);

kp = 0;                                % case 1
km = 1;                                % case 1


out(1,:) =  km*1*y(2,:);                % == zero molecules
for l = 2:nn-1,
  out(l,:) = kp*(l-2)*y(l-1,:)+km*l*y(l+1,:)-(kp+km)*(l-1)*y(l,:);
                                        % == from 1 to nn-2 molecules
end
out(nn,:) =  kp*(nn-2)*y(nn-1,:)-(kp+km)*(nn-1)*y(nn,:);    
                                        % ==  nn-1 molecules
                                                           
                                                            

