function Chapter_4_Figure_4

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This matlab file reproduces simulation studies in the book:
% Systems Biology: Mathematical modeling and model analysis
% by A. Kremling
%
% It is related to Figure 4 in Chapter 4
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% --- parameters: see function 'calculation'
% --- calculation: see function 'calculation'

% --- plotting
figure (1)
subplot(121); calculation(1000);
title('For 1000 measurement points one obtains a normal distribution')
subplot(122); calculation(25)
title('For 25 measurement points, a distortion can be seen')

%_________________________________________

function calculation(numb_meas)
disp('')
disp('Simulation takes a few minutes!')

%input: 'numb_meas' is the number of measurements points. e.g 1000
%or 25

% --- parameters

sig = 0.1;      % sigma
b_opt = 2;      % optimal parameter (e.g. identified by estimating)
boot = 6000;    % number of bootstrapping-cycles

xx = 0:(25/numb_meas):25;       % measurement points
xx = xx';

% --- calculation

yy = 1./(b_opt+xx); 

% calculates tangent & FIM

fa = -1./(b_opt+xx).^2;

% confident intervals with FIM

FIM = sum(fa.^2)/sig^2;
sig_b = sqrt(1/FIM);

disp('  ')
disp('Output intervals b_opt = 2')
disp('Fisher-Info-Matrix')
disp([b_opt-2*sig_b b_opt+2*sig_b])

% --- bootstrapping

for ll = 1:boot,
  
  lb = [0.001];
  ub = [200];

  % bring  noise into the data
  for k = 1:length(xx),
    yy_p(k) =  sig*randn+yy(k);
  end
    yy_p = yy_p';
  
   % random startvalue of parameter
   para_0 = [2*rand];

   
  opt = optimset('LargeScale','on','DiffMaxChange',1e7,'MaxFunEvals',15000,'Display','off','TolX',1e-10,'TolFun',1e-10,'MaxIter',1000); 

   % estimating parameter
   para_b(ll) = lsqnonlin(@targetpara,para_0,lb,ub,opt,xx,yy_p,sig);  
 

   clear yy_p

end


% analysis boot

para_b_sort = sort(para_b);
 
p_low =  para_b_sort(round(0.025*length(para_b)));
p_up =   para_b_sort(round(0.975*length(para_b)));
 
[nn,pos] = hist(para_b_sort,30);
[max_p,jj] = max(nn);
max_v = pos(jj);
 
meann = mean(para_b);
shape = (p_up-max_v)/(max_v-p_low);
shape2 = (p_up-meann)/(meann-p_low);
bias_2 = 100*abs(max_v-mean(para_b))/max_v;
bias = 100*abs(mean(para_b)-b_opt)/b_opt;


% --- plotting

nbins=100;               % number of bins
bincenter=0:5/nbins:5;   % bins location
nnbins=hist(para_b_sort,bincenter);  %counts for each Bin. 
hist(para_b_sort,bincenter);

hold on
pd=fitdist(para_b_sort','Normal');
pdf2=pdf(pd,para_b_sort);
plot(para_b_sort,max(nnbins)/max(pdf2)*pdf2,'r','Linewidth',2)

xlabel('parameter b'), ylabel('#'), xlim([0 5])

disp('  ')
disp('Bootstrapping')
disp([p_low p_up])

%_________________________________________

function z = targetpara(para_fit,data1,data2_r,sig)

%calculation with model 

para_a = para_fit(1);

data2_f =  1./(para_a+ data1);

z = (data2_f - data2_r)./sig;

