function Chapter_4_Figure_6

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This matlab file reproduces simulation studies in the book:
% Systems Biology: Mathematical modeling and model analysis
% by A. Kremling
%
% It is related to Figure 6 in Chapter 4
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% --- parameters: x_max = 4

x = 0:1:4;  x = x';
lx = length(x);
p = [1;10];
X = [ones(lx,1) x];

% --- calculation and plotting Figure 4.6 left
A = (X'*X)/2;
figure(1)
subplot(121)
draw_elipse(A,1,1,'b');

% --- parameters: x_max = 32
x = 0:8:32;  x = x';
lx = length(x);
p = [1;10];
X = [ones(lx,1) x];

% --- calculation and plotting Figure 4.6 left
y = X*p;
A2 = (X'*X)/2;
subplot(121)
draw_elipse(A2,1,1,'b--');
title('Ellipse for the range till x = 4 (continuous) and for the range x = 32 (dashed)')


%_________________________________________________

% --- parameters

p = [1;10];
x_l = 1:50;

% --- calculation Figure 4.6 right

for l = 1:length(x_l),
  x = 0:x_l(l)/4:x_l(l);  x = x';
  lx = length(x);
  X = [ones(lx,1) x];
  A = (X'*X)/2;
  sigma_p(l,:) =sqrt(diag(inv(A)));
end

% --- plotting Figure 4.6 right
figure(1), subplot(122), plot(x_l,sigma_p(:,2)/p(2),'b',[0 50],[0.01 0.01],'k')
xlabel('x'), ylabel('\sigma_p_2/p_2 ')
title('Progression of the relative standard deviation of parameters p_2.')

%_________________________________________________

% Exercise 4.2: Generate data for a straight line with parameter p1= 1 and p2= 10. In
%the chapter, it was shown that the accuracy for p1 couldn�t be improved by
%increasing the maximal value of x. Try to increase the number of data points 
% N. How large must be N to get ?p1/p1 ? 30% while the maximal x = 32.

disp(' ')
disp('Solution also for Exercise 4.2: See Figure 2 ')
disp(' ')

% --- parameters
clear sigma_p
d_l = 2:-0.1:0.1;

% --- calculations
for l = 1:length(d_l), 
  x = 0:d_l(l):32;  x = x';
  lx = length(x);
  X = [ones(lx,1) x];
  A = (X'*X)/2;
  sigma_p(l,:) = sqrt(diag(inv(A)));
end

% --- plotting
figure(2), plot(32./d_l,sigma_p(:,1)/p(1),'b',[0 350],[0.3 0.3],'k')
xlabel('N'), ylabel('\sigma_p_1/p_1 ')
title('Solution of exercise 4.2')
xlim([0 300])

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [para_old1,para_old1b,para_old2,para_old2b]=draw_elipse(W,fig_number,holdd,color,center,confi);
%
% draw infos of FIM
% function [para_old1,para_old1b,para_old2,para_old2b] 
%                            = draw_elipse(W,fig_number,holdd,color);
%  W == FIM
%  fig_number == Number of Figure
%  holdd == 1 hold on == 0 hold off
%  color == Color of the plot
%  center == shows the ellipse around vector center
%  confi = [df,chi] == [degree of freedom (1 or 2); conf (68.3% or95%)]


if nargin == 1,
  fig_number = 111;
  holdd = 0;
  color = 'b';
  center = [0 0];
  confi(2) = 1;  % df = 1  == one parameter
  confi(1) = 68.268949; % = 68.3 % == 1 times std dev.
end


if nargin == 2,
  holdd = 0;
  color = 'b';
  center = [0 0];
  confi(2) = 1;  % df = 1  == one parameter
  confi(1) = 68.268949; % = 68.3 % == 1 times std dev.
end

if nargin == 3,
  color = 'b';
  center = [0 0];
  confi(2) = 1;  % df = 1  == one parameter
  confi(1) = 68.268949; % = 68.3 % == 1 times std dev.
end

if nargin == 4,
  center = [0 0];
  confi(2) = 1;  % df = 1  == one parameter
  confi(1) = 68.268949; % = 68.3 % == 1 times std dev.
end

if nargin == 5,
  confi(2) = 1;  % df = 1  == one parameter
  confi(1) = 68.268949; % = 68.3 % == 1 times std dev.
end

% --- eigenvalues and vectors

[eigvec,eigval] = eig(W);
eigval = diag(eigval);

% --- confidence

ichi = confi(1); df = confi(2);
delta_phi = chi2inv(ichi/100,df);
%delta_phi = finv(ichi/100,df,5);

%  --- calculation into new coordinates

start_para1 = sqrt(delta_phi/max(eigval(1)));
inter = 2*start_para1/500;
para1 = -start_para1 : inter : start_para1;

for k = 1:length(para1),
 zip(k) = (delta_phi-eigval(1)*para1(k)^2)/eigval(2);
 para21(k) = sqrt(zip(k));
 para22(k) = -para21(k);
end; 

%  --- back transformation

para_old1 = eigvec(1,1)*para1+eigvec(1,2)*para21;
para_old1b = eigvec(1,1)*para1+eigvec(1,2)*para22;
para_old2 = eigvec(2,1)*para1+eigvec(2,2)*para21;
para_old2b = eigvec(2,1)*para1+eigvec(2,2)*para22;

figure(fig_number); 
if holdd == 1,
 hold on;
else
 hold off
end;

plot(para_old1+center(1),para_old2+center(2),color,para_old1b+center(1),para_old2b+center(2),color);
xlabel('parameter p_1'), ylabel('parameter p_2')


