function Chapter_5_Figure_2_and_Figure_4

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This matlab file reproduces simulation studies in the book:
% Systems Biology: Mathematical modeling and model analysis
% by A. Kremling
%
% It is related to Figure 2 and Figure 4 in Chapter 5
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

close all;

% --- Parameters

t=0:0.1:80;             % [s]
p.k1 = 100;             % [l/gh]
p.k2 = 10;              % [1/h]
p.k3 = 1.5;             % [1/h]
C01 = [10 0.1 0 0 ];    % [g/l], [S E ES P]
C02 = [10 5 0 0 ];      % [g/l]

% --- calculation

% --- calling up the ODE-solver

[t1,conc1] = ode15s(@rs_kinetiken,t,C01,[],p);
[t2,conc2] = ode15s(@rs_kinetiken,t*3/40,C02,[],p);

% --- decomposition of the result-matrix

cs  = conc1(:,1);
ce  = conc1(:,2);
ces = conc1(:,3);
cp  = conc1(:,4);

cs2  = conc2(:,1);
ce2  = conc2(:,2);
ces2 = conc2(:,3);
cp2  = conc2(:,4);

% --- plotting: Figure 5.2

figure(1)
subplot(121);plot(t1,cs,'k',t1,cp,'k--');xlabel('time');
ylabel('S (-) P (--)');
title({'Simulation of the whole system of differential Equations (5.3)';...
    ' with the initial conditions S_0= 10 >> E_0= 0.1'})
subplot(122);plot(t1,ce,'k',t1,ces,'k--');xlabel('time');
ylabel('E (-) ES (--)');
title({'Because of the high affinity of the substrate, the free enzyme quickly changes into the complex and the concentrations'...
    'of E and ES stay constant for a great period of time'})

% --- plotting: Figure 5.4

figure(2)
subplot(121);plot(t2,cs2,'k',t2,cp2,'k--');xlabel('time');
ylabel('S (-) P (--)'); 
title({'Simulation of the whole differential equation system (5.3)';...
    'with the initial conditions S_0= 10 ? E_0 = 5.'})
subplot(122);plot(t2,ce2,'k',t2,ces2,'k--');xlabel('time');
ylabel(' E (-) ES (--)');
title({'In the first timestep, a part of the substrate is bound by the enzyme'...
    'Then saturation of the enzyme is reached.'})
%________________________________________________________

function dcdt=rs_kinetiken(t,x,p)

% --- Decomposition of state-vector 

con_cs  = x(1);
con_ce  = x(2);
con_ces = x(3);
con_cp  = x(4);

% --- Calculation of time derivative: differential equation system (5.3)

dcsdt = -p.k1*con_ce*con_cs +  p.k2*con_ces;
dcedt = -p.k1*con_ce*con_cs + (p.k2+p.k3)*con_ces;
dcesdt=  p.k1*con_ce*con_cs - (p.k3+p.k2)*con_ces;
dcpdt =  p.k3*con_ces;

% --- restoration vector
dcdt = [dcsdt; dcedt; dcesdt; dcpdt];

