function Chapter_5_Figure_7_and_Figure_8

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This matlab file reproduces simulation studies in the book:
% Systems Biology: Mathematical modeling and model analysis
% by A. Kremling
%
% It is related to Figure 7 and Figure 8 in Chapter 5
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
close all;

% --- parameters

S = 0:0.1:10;
Ks = 1;
I = [0;1;2;5;10];

% --- calculation: Figure 5.7
for i = 1:length(I)
 r(:,i) = S./(Ks*(1+I(i)) + S);
end

% --- plotting
figure (1)
plot(S,r(:,1),'k',S,r(:,2),'k--',S,r(:,3),'k-.',S,r(:,4),'k:')
xlabel('S');ylabel('r(S)');
text(5,0.75,' \downarrow influence I/Ki');
title('Influence of an inhibitor I on the rate r. The solid curve shows the Michaelis-Menten kinetics.')

%_________________________________________________

% --- calculation: Figure 5.8

A = [2;5;10];
for i = 1:length(A)
  rm = A(i)/(1+A(i));
  K = Ks/(1+A(i));
  r2(:,i) = rm*S./(K + S);
end

% --- plotting
figure(2)
plot(S,r(:,1),'k',S,r2(:,1),'k--',S,r2(:,2),'k-.',S,r2(:,3),'k:')
xlabel('S');ylabel('r(S)');
text(5,0.65,' \uparrow influence A/Ka');
title('Influence of an activator on the rate r. The solid line indicates the Michaelis-Menten kinetics')

