function Chapter_6_Exercise_2

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This matlab file reproduces simulation studies in the book:
% Systems Biology: Mathematical modeling and model analysis
% by A. Kremling
%
% It is related to Exercise 2 in Chapter 6
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



disp('Complete model')

% --- parameters

p.d10 = 1.3e-5*10; % here you can set and modify the value of D10
p.r10 = 1.3e-3;
p.d20 = 1.3e-3;
p.r20 = 2.0e-3;
p.K1 =  1.0e-4; 
p.K2 =  1.0e-3;
p.alpha = 10.0;

% --- calculation: complete model

start=[p.d10/10 p.d20/10 p.r10/30 p.r20/30];

r10 = 1e-5:1e-5:2e-3;
r20 = 1e-5:2e-5:2e-3;

for i = 1:length(r10),     % alternatively simulate values for R10 or R20
%for i = 1:length(r20),

 p.r10 = r10(i);
% p.r20 = r20(i);

 opp = optimset('Display','off','Algorithm','levenberg-marquardt');
 [x,fval,exit]=fsolve(@mod1,start,opp,p);
 
 d1(i) = x(1);
 d2(i) = x(2); 
 r1(i) = x(3);
 r2(i) = x(4);

 r2d1(i)  = r2(i)*d1(i)/p.K2;
 r1r2d1(i) =  p.alpha*r1(i)*r2(i)*d1(i)/(p.K1*p.K2); 
 r2d2(i) =  r2(i)*d2(i)/p.K2;

 psi1(i) = (r2d1(i)+r1r2d1(i))/p.d10; 
 psi2(i) = r2d2(i)/p.d20;
 
 start = [d1(i) d2(i) r1(i) r2(i)];

end;

% --- plotting: complete model

figure,plot(r10,psi1','--');hold on
title({'course of \Psi_1 as a function of R_1 (R_2 is constant)'...
    'for the complete and reduced model (solid line)'})

%______________________________________________________


disp('Reduced model')

% --- parameters

start1=[r20/30];
start2=[p.d10/10 p.r10/30];

r10 = 1e-5:1e-5:2e-3;
%r20 = 1e-5:2e-5:2e-3;

% --- calculation: reduced model

for i = 1:length(r10),

% level one describes interaction of R2 with both binding sites
% psi_r is the fraction of R2 on binding site D1
% psi2_r is the fraction of R2 on binding site D2
  
  p.r10 = r10(i);

 [x,fval]=fsolve(@mod3,start1,opp,p);     
 r2(i) = x(1);
 d1(i) = p.d10/(1+r2(i)/p.K2);
 d2(i) = p.d20/(1+r2(i)/p.K2);
 psi_r(i) = r2(i)*d1(i)/(p.K2*p.d10);
 psi2_r(i) = r2(i)*d2(i)/(p.K2*p.d20);
 start1 = r2(i);
 
% level two describes interaction of R1 with binding site D1
% psi1_r is the fraction of R1 on binding site D1
 
 
 [x,fval]=fsolve(@mod2,start2,opp,p,psi_r(i));
 d11(i) = x(1);
 r1(i) = x(2); 

 K(i) = (1-psi_r(i))/psi_r(i);
 psi1_r(i) = (d11(i)/K(i) + p.alpha*r1(i)*d11(i)/(K(i)*p.K1))/p.d10; 

 start2 = [d11(i) r1(i)];
 
end;

% --- plotting: reduced model
plot(r10,psi1_r)
xlabel('R1'),ylabel('\Psi_1 (---), \Psi_1_r')

%______________________________________________________
%______________________________________________________

function ze = mod1(y,p)

% ----------------------------- 

d1 = y(1); 
d2 = y(2);
r1 = y(3);
r2 = y(4);

% ----------------------------- 

ze = zeros(4,1);
ze(1) = p.d10 - d1 - d1*r1/p.K1 - d1*r2/p.K2 - p.alpha*d1*r1*r2/(p.K1*p.K2);
ze(2) = p.d20 - d2 -  d2*r2/p.K2;
ze(3) = p.r10 - r1 -  d1*r1/p.K1 -  p.alpha*d1*r1*r2/(p.K1*p.K2);
ze(4) = p.r20 - r2 -  d2*r2/p.K2 -  p.alpha*d1*r1*r2/(p.K1*p.K2);

%_____________________________________________________


function ze = mod2(y,p,psi)

% ----------------------------- 

d11 = y(1);
r1 = y(2);

% ----------------------------- 

ze = zeros(2,1);
K = (1-psi)/psi;
ze(1) = p.d10 - d11 - d11/K - d11*r1/p.K1 -  p.alpha*d11*r1/(K*p.K1);
ze(2) = p.r10 - r1 -  d11*r1/p.K1 -  p.alpha*d11*r1/(K*p.K1);  

%_____________________________________________________

function ze = mod3(y,p)

r2 = y(1);
d1 = p.d10/(1+r2/p.K2);
d2 = p.d20/(1+r2/p.K2); 

% ----------------------------- 

ze = p.r20 - r2 -  d2*r2/p.K2 -  d1*r2/p.K2;