function Chapter_7_Figure_10

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This matlab file reproduces simulation studies in the book:
% Systems Biology: Mathematical modeling and model analysis
% by A. Kremling
%
% It is related to Figure 10 in Chapter 7
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% -------------- figure 7.10: signal-response-curve Effector --- %
close all;

% --- parameter

S0=[0:0.1:60];
E0=[0:25:50];
a=0;
p.Ke=0.01;
p.k1=10;
p.k2=1;
p.R0=1;

% --- calculation

for n=1:length(E0)
     p.E0=E0(n);
     for i=1:length(S0)
            p.S0=S0(i);
	    pp = (p.Ke+p.E0-p.S0); q = -p.S0*p.Ke;  
	    S(i,n) = -pp/2+sqrt(pp^2/4-q);         
      	    RP(i,n)=(S(i,n)*p.R0)/(S(i,n)+p.k2/p.k1); 
     end;

end

% --- plotting

for k=1:length(E0)
       subplot(121);
       plot(S0,RP(:,k),'k');hold on
       text(10,0.5,' \rightarrow Effector');
       xlabel('S_0');ylabel('R^P');
       subplot(122);
       plot(log(S0),log(RP(:,k)./(1-RP(:,k))),'k');hold on
       text(0,-2,' \rightarrow Effector');
       xlabel('log S_0');ylabel('R^P');
end

subplot 121
title({'Influence of the effector on the result:';' With higher concentrations of the effector, the graph shifts from hyperbolic to sigmoid behavior'}')
subplot 122
title('This can be illustrated with the Hill coefficient')


end