function Chapter_7_Figure_12_to_14

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This matlab file reproduces simulation studies in the book:
% Systems Biology: Mathematical modeling and model analysis
% by A. Kremling
%
% It is related to Figure 12 to 14 in Chapter 7
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

disp(' ')
disp(' Simulation need some time!')
disp(' ')

% -------------- figure 7.12 - 7.14: oscillating systems --- %


% --- parameters

p.k0 = 4;p.k1 = 1;p.k2 = 1;
p.k3 = 1;p.k4 = 1;p.k22= 1;
p.k5 = 0.1;p.k6 = 0.075;p.E0 = 1;
p.J3=0.3;p.J4=0.3;
tsp = [0:1:250];                     % interval of integration. 
M0 = [1.4; 2];                       % initial conditions 
p.S=[0.2];
S=[0:0.005:0.5];

% --- calculation: Figure 7.12 left.

[t,M]=ode45(@Differential_equations,tsp,M0,[],p);   % solves the differential equations system

X1 = M(:,1);
R1 = M(:,2);

% --- plotting

figure (1)
subplot(121)
plot(t,X1, 'b',t,R1,'b--')
xlabel('Time');ylabel('R (--), X');title('Time response of X and R for a special value of S');

%_________________________________________________


% --- calculation: Figure 7.12 right. 

for i=1:length(S)
    p.S=S(i);
    [t,M]=ode15s(@Differential_equations,tsp,M0,[],p);

X = M(200:250,1);
R = M(200:250,2);

Max(i) = max(R);
Min(i) = min(R);

end

% --- plotting

subplot(122);plot(S,Max,'bo',S,Min,'bo')
xlabel('R');ylabel('S');title({'Plot of the stationary system of R in dependence of S';...
    'The maximum and minimum values of the oscilaations are shown as symbols'})


%_________________________________________________


% --- calculation: Figure 7.13 Left. 

Snew=[0.01;0.2;0.4;0.5];
figure(2)
for k = 1:length(Snew)

p.R=0:0.01:2;
u=p.k3*p.R;
v=p.k4;
J=p.J3;
K=p.J4;

p.EP=2.*u.*K./(v-u+v.*J+u.*K+sqrt((v-u+v.*J+u.*K).^2-4*(v-u).*u.*K));
Xnew1(:,k)=(p.k0.*p.EP+p.k1.*Snew(k)-p.k2.*p.R)./(p.k22.*p.R);
Xnew2=p.k5.*p.R./p.k6;
end

% --- plotting
subplot(121)
plot(Xnew1(:,1),p.R,'b:',Xnew1(:,4),p.R,'b:',Xnew1(:,2),p.R, 'b',Xnew1(:,3), p.R, 'b', Xnew2, p.R,'b--');
hold on; 
xlabel('X');ylabel('R');title({'Nullclines for different values of S';...
    'The values of S for wich the system oscillates are solid '})
axis([0 2 0 2])


%_________________________________________________

% --- calculation: Figure 7.13 right. 

p.S=0.2;  % for this S value the system oscillates.

M0 = [0.5; 2];                                      % Initial condition one
[t,M]=ode45(@Differential_equations,tsp,M0,[],p);   
X1 = M(:,1); R1 = M(:,2);


M0 = [1; 1];                                      % Initial condition two
[t,M]=ode45(@Differential_equations,tsp,M0,[],p);   
X2 = M(:,1); R2 = M(:,2);


M0 = [1; 0.2];                                      % Initial condition three
[t,M]=ode45(@Differential_equations,tsp,M0,[],p);   
X3 = M(:,1); R3 = M(:,2);

M0 = [1.4; 2];                                      % Initial condition four
[t,M]=ode45(@Differential_equations,tsp,M0,[],p);   
X4 = M(:,1); R4 = M(:,2);

% --- plotting

subplot (122); 
plot(X1,R1,'b--', X2, R2, 'b:', X3, R3, 'b:', X4, R4, 'b:');
xlabel('X');ylabel('R');
title('Limit cycle plotted for different initial values ');


%_________________________________________________

% --- calculation: Figure 7.14 left. 
clear Max Min
S = 0.2;
k0 = 2:0.05:6; 
for i=1:length(k0)
    p.k0 = k0(i);
    p.S=S;
    [t,M]=ode15s(@Differential_equations,tsp,M0,[],p);

X = M(200:250,1);
R = M(200:250,2);

Max(i) = max(R);
Min(i) = min(R);

end

% --- plotting
figure(3); 
subplot (121); plot(k0,Max,'bo',k0,Min,'bo')
line([3.5 3.5],[0 2], 'Color', 'k'), line([4.5 4.5],[0 2], 'Color', 'k')
xlabel('Parameter k_0');ylabel('R');
title('Parameter study for parameter k_0');
text(3.8,1,'Oscillations')


%_________________________________________________

% --- calculation: Figure 7.14 right.

clear Max Min
S = 0.2;
p.k0 = 4;
k2 = 0.25:0.025:2; 
for i=1:length(k2)
    p.k2 = k2(i);
    p.S=S;
    [t,M]=ode15s(@Differential_equations,tsp,M0,[],p);

X = M(200:250,1);
R = M(200:250,2);

Max(i) = max(R);
Min(i) = min(R);
end

% --- plotting
figure(3); 
subplot(122) ; plot(k2,Max,'bo',k2,Min,'bo')
line([0.75 0.75],[0 2], 'Color', 'k'), line([1.2 1.2],[0 2], 'Color', 'k')
xlabel('parameter k_2');ylabel('R');title('parameter study for k_2');
text(0.8,0.8,'Oscillations')


%______________________________________________

function dMdt=Differential_equations(t,x,p)

% --- decomposition of the state-vector

xe =  x(1);
r  = x(2);

% --- calculation of time-derivations

E    = G(p.k3*r,p.k4,p.J3,p.J4);
dXdt = p.k5*r-p.k6*xe;
dRdt = p.k0*E+p.k1*p.S-p.k2*r-p.k22*xe.*r;

dMdt = [dXdt;dRdt];

% ----------------------------------------------------------------------- %

function Enzyme=G(u,v,J,K) 

% Golbeter-Koshland function
Enzyme=2*u.*K/(v-u+v*J+u.*K+sqrt((v-u+v*J+u.*K)^2-4*(v-u)*u.*K));




