function Chapter_7_Figure_16

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This matlab file reproduces simulation studies in the book:
% Systems Biology: Mathematical modeling and model analysis
% by A. Kremling
%
% It is related to Figure 16 in Chapter 7
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
close all;

% --- calculation

[t,y] = ode15s(@f,[0 20],[0 0 0.01]);

% --- plotting

plot(t,y(:,1),'k',t,y(:,2),'k--',t,y(:,3),'k-.');
ylim([0 1.1]);
hold on
line([0 20],[1 1],'color','k');
xlabel('Time');title({'Time response for the for feedback reaction. Continuous line: No regulation'...
    ;'Dashed line: negative feedback reaction. Semicolon: positive feedback reaction'});

 

% ----------------------------------------------------------

function dy = f(t,y)

a = y(1); %no regulation
b = y(2); %negative autoregulation
c = y(3); %positive autoregulation

% --- parameter

K=1; n=1; ksyn=1; ksyn1=2; ksyn2=2; kab=1;

f1=ksyn;
f2=ksyn1./(1+(b./K).^n);
f3=ksyn2.*((c./K).^n)./(1+(c./K).^n);

dy(1)=f1-kab.*y(1);
dy(2)=f2-kab.*y(2);
dy(3)=f3-kab.*y(3);


g1 = 1-a;
g2 = 2./(1+b)-b;
g3 = 4*(c.^2)./(1+c.^2) - c;

out=[g1;
     g2;
     g3];

dy=dy(:);