function Chapter_7_Figure_17

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This matlab file reproduces simulation studies in the book:
% Systems Biology: Mathematical modeling and model analysis
% by A. Kremling
%
% It is related to Figure 17 in Chapter 7
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

close all;

% --- calculation: Figure 7.17 right

sim0=[0.1 0.25 0.275 0.5 1];  % initial conditions 

[t,G]=ode15s(@diff,[0 10],(sim0));  % solves the differential equations system for five
                                    % different initial conditions. 

% --- plotting

subplot(122);
plot(t,G,'k'); hold on
line([0 10],[0.268 0.268],'Color','b'); xlabel('time'); ylabel('Protein G');
title('Simulation for k_s_y_n_2(S) = 4')

%_________________________________________________


% --- calculation: Figure 7.17 left

ksyn_1=2:0.001:5;
Gsteady1=ksyn_1/2+0.5.*sqrt(ksyn_1.^2-4);
Gsteady2=ksyn_1/2-0.5.*sqrt(ksyn_1.^2-4);

% --- plotting

subplot(121);
plot(ksyn_1,Gsteady1,'k');hold on
plot(ksyn_1,Gsteady2,'k--');
xlim([0 5]);grid on
xlabel('Parameter k_s_y_n'); ylabel('steady states');
title({'steady states in dependence of k_s_y_n_2(S).';'A supercritical bifurcation occurs for k_s_y_n_2(S) = 2'})

%_________________________________________________

    
function [dG]=diff(t,G);

ksyn=4;

dG=ksyn.*((G.^2.)./(1+G.^2))-G;

dG=dG(:);
    end

end