function Chapter_7_Figure_20

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This matlab file reproduces simulation studies in the book:
% Systems Biology: Mathematical modeling and model analysis
% by A. Kremling
%
% It is related to Figure 20 in Chapter 7
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% --- initial parameters and calculation: S1=5 and S2=1
p.s1 = 5; 
p.s2 = 1; 
y0 = [0.5 0.5];
time = 0:0.1:10;

[t,y]=sys_toggle(p,y0,time); 
ye = y(end,:);

% --- calculation: S1=1 and S2=5

p.s1 = 1; 
p.s2 = 5; 
time = 10:0.1:20;

[t2,y2]=sys_toggle(p,ye,time); 

ye = y2(end,:);

% --- calculation: S1=5 and S2=1
p.s1 = 5; 
p.s2 = 1; 
time = 20:0.1:30;

[t3,y3]=sys_toggle(p,ye,time); 

ye = y3(end,:);

% --- calculation: S1=1 and S2=5

p.s1 = 1; 
p.s2 = 5; 
time = 30:0.1:40;

[t4,y4]=sys_toggle(p,ye,time); 


% --- plotting
figure
subplot(121);plot([t;t2;t3;t4],[y;y2;y3;y4]),grid, xlabel('time'), ylabel('X and Y')
title('Time response of toggling between X and Y (S1= 5 or 1 and S2= 1 or 5)')
subplot(122),plot([y(:,1),y2(:,1),y3(:,1),y4(:,1)],[y(:,2),y2(:,2),y3(:,2),y4(:,2)],'b'),grid
xlabel('X'), ylabel('Y')
title('Trend in the phase plane. The starting value is X = 0.5, Y = 0.5.')

%___________________________________________________________

function [t,y]=sys_toggle(p,y0,time)

options = odeset('RelTol',1e-6,'AbsTol',1e-9,'Vectorized','on');

[t,y] = ode15s(@f,time,y0,options,p);

% ----------------------------------------------------------

function out = f(t,j,p)

x = j(1,:);
y = j(2,:);

out =[p.s1./(1+y) - x
	  p.s2./(1+x) - y];


