function Chapter_7_Figure_23

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This matlab file reproduces simulation studies in the book:
% Systems Biology: Mathematical modeling and model analysis
% by A. Kremling
%
% It is related to Figure 23 in Chapter 7
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% --- parameters

D = 3;
nr_grid = 120;
l = 1.0;
d_z = l/nr_grid;
k_k = 2.0;
M_0 = 10;
k_p = 12.5;
kin = 1.0;
phos = 0.2;

para = [D;nr_grid;l;d_z;k_k;M_0;k_p;kin;phos];  % parameters are in a vector summarized


% --- calculation
y0 = [0.1*ones(nr_grid,1);0.5*ones(nr_grid,1)]; % initial conditions

tspan = 0:0.02:5;                               % interval of integration
[t,y] = ode15s(@fun_sys,tspan,y0,[],para);

M0  = D*y(:,1+nr_grid)/(D+k_k*kin*d_z);
M0p = y(:,1)+k_k*kin*d_z*M0/D; 

for i = 1:nr_grid,
  Mp(:,i) = y(:,i);
end

for i = nr_grid+1:2*nr_grid,
  M(:,i-nr_grid) = y(:,i);
end

for k =1:nr_grid,
  st_Mp(k) = Mp(length(t),k);
  st_M(k) = M(length(t),k);
end

st_M0 = M0(length(t));
st_M0p = M0p(length(t));

st = [st_M0;st_M'];
st_p = [st_M0p;st_Mp'];

len = [0;d_z*(1:nr_grid)'];

% --- plotting 

figure(1);plot(len,st,'--',len,st_p,'r')
title('Stationary local profile with the lengh l = 1 of the phosphorylated and nonphosphorylated components.')
xlabel('length z'), ylabel('M^P (solid) and M')

figure(2);subplot(121),plot(t,M0p,t,Mp(:,1),t,Mp(:,nr_grid))
title('time course of M_0^P and M_P'), xlabel('time'), legend('M_0^P','M_P(z=1/120)','M_P(z=1)')

subplot(122);plot(t,M0,t,M(:,10))
title('time course of M_0 and M'), xlabel('time'), legend('M_0','M')

% ---------------------------------------------------------
%     increase of the concentration of the phosphorylated component 
% ---------------------------------------------------------

% --- parameters

y0 = [st_Mp st_M];   % new initial conditions 

phos = 3*0.2;        % concentration increase
para = [D;nr_grid;l;d_z;k_k;M_0;k_p;kin;phos];

% --- calculation

[t,y] = ode15s(@fun_sys,tspan,y0,[],para);

M0  = D*y(:,1+nr_grid)/(D+k_k*kin*d_z);
M0p = y(:,1)+k_k*kin*d_z*M0/D; 

for i = 1:nr_grid,
  Mp(:,i) = y(:,i);
end

for i = nr_grid+1:2*nr_grid,
  M(:,i-nr_grid) = y(:,i);
end

for k =1:nr_grid,
  st_Mp(k) = Mp(length(t),k);
  st_M(k) = M(length(t),k);
end

st_M0 = M0(length(t));
st_M0p = M0p(length(t));

st2 = [st_M0;st_M'];
st_p2 = [st_M0p;st_Mp'];

% --- plotting

figure(11);plot(len,st2,'b--',len,st_p2,'r--')
xlabel('length z'),ylabel('M^P (red) and M')
title({'Stationary local profile of the phosphorylated and nonphosphorylated components';...
   'after concentration increase'})

figure(21);subplot (121),plot(t,M0p,t,Mp(:,1),t,Mp(:,nr_grid))
title('time course of M_0^P and M_P after concentration increase'), xlabel('time'), legend('M_0^P','M_P(z=1/120)','M_P(z=1)')

subplot(122);plot(t,M0,t,M(:,10))
title('time course of M_0 and M after concentration increase'), xlabel('time'), legend('M_0','M')


%_____________________________________________________________
%_____________________________________________________________


function out = fun_sys(t,y,para)

D = para(1);
nr_grid = para(2);
l = para(3);
d_z = l/nr_grid;
k_k = para(5);
M_0 = para(6);
k_p = para(7);
kin = para(8);
phos = para(9);

M0  = D*y(1+nr_grid)/(D+k_k*kin*d_z);
M0p = y(1)+k_k*kin*d_z*M0/D;

out(1) =  D*(M0p-2*y(1)+y(2))/d_z^2 - k_p*phos*y(1);

for i = 2:nr_grid-1,
  
  out(i) = D*(y(i-1)-2*y(i)+y(i+1))/d_z^2 - k_p*phos*y(i);

end

out(nr_grid) = out(nr_grid-1);

% ------------------

out(1+nr_grid) =  D*(M0-2*y(1+nr_grid)+y(2+nr_grid))/d_z^2 + k_p*phos*y(1);

for i = 2+nr_grid:2*nr_grid-1,
  
  out(i) = D*(y(i-1)-2*y(i)+y(i+1))/d_z^2 + k_p*phos*y(i-nr_grid);

end

out(2*nr_grid) = out(2*nr_grid-1);


out = out';



