function Chapter_7_Figure_3

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This matlab file reproduces simulation studies in the book:
% Systems Biology: Mathematical modeling and model analysis
% by A. Kremling
%
% It is related to Figure 3 in Chapter 7
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
close all;
% --- parameter

p.k1=1;
p.k2=1;
p.K1=0.05;
p.K2=0.05;
p.R0=1;
S=0:0.1:3;
RP0=0;

% --- calculation

% synthesis rates in dependence on the signal Rp for four constant S
% values.

RP1=[0:0.01:p.R0];
Synthesis1=(p.k1*0.25*(p.R0-RP1))./(p.K1+p.R0-RP1);      % S=0.25
Synthesis2=(p.k1*1*(p.R0-RP1))./(p.K1+p.R0-RP1);         % S=1
Synthesis3=(p.k1*1.5*(p.R0-RP1))./(p.K1+p.R0-RP1);       % S=1.5
Synthesis4=(p.k1*2*(p.R0-RP1))./(p.K1+p.R0-RP1);         % S=2

% Degradation rate
Depletion=(p.k2*RP1)./(p.K2+RP1);

%signal response graph
op = optimset('fsolve');
op = optimset('Display','off');

for i=1:length(S)
     p.S=S(i);
     RP(i)=fsolve(@XX,0.5,op,p);
end

% --- plotting

subplot(121);
plot(S,RP,'k');
title('Signal response graph: Switching behaviour');
xlabel('S');ylabel('R_P');axis([0 3 0 1.01]);

subplot(122);
plot(RP1,Synthesis1,'k--',RP1,Synthesis2,'k--',RP1,Synthesis3,'k--',RP1, Synthesis4,'k--', RP1,Depletion,'k')
title('Graphical construction of the signal response graph');
xlabel('R_P');ylabel('Rate');
text(0.4,1,'S \rightarrow'); text(0.2,1.9,'Syntheses (dotted)');text(0.6,1.9,'Degradation (solid)');

end




function x = XX(RP,p)
x=p.k1*p.S*(p.R0-RP)/(p.K1+p.R0-RP)-p.k2*RP/(p.K2+RP);
end