function Chapter_7_Figure_5

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This matlab file reproduces simulation studies in the book:
% Systems Biology: Mathematical modeling and model analysis
% by A. Kremling
%
% It is related to Figure 5 in Chapter 7
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

close all;

% --- parameter

p.k1=2;
p.k2=2;
p.k3=1;
p.k4=1;
p.S=5;

S=0:0.1:1.5;

% --- calculation

% steady states calculation

Xss=p.k3*S/p.k4;
Rss=p.k1*S./(p.k2*Xss);

% Signal response curve calculation
tspan=[0 20];
y0=[1 1];
[t,V]=ode45(@diff_1,tspan ,y0,[],p);

% --- plotting

figure
subplot(121)
plot(S,Xss,'k', S,Rss,'k--')
text(0.5,0.3,'X'), text(0.25,1.1,'R')
xlabel('S')
title('Adaptive behavior: quantity X depends of S while R is changed independently')

subplot(122)
plot(t,V(:,1),'k'); xlabel('time'), ylabel('R(t)')
axis([0 20 1 1.5]);
title('A dynamic response of the system occurs if S is changed.')
end

function [dV]=diff_1(t, V, p);

% V(1)--> R , V(2)--> X

% stimulation of the system by signal S
if t<=7
        S=2;
else if t>7 & t<14
        S=3;
    else
        S=4;
    end
end
        
        
dV(1)=p.k1*S-p.k2*V(2).*V(1);
dV(2)=p.k3*S-p.k4*V(2);

dV=dV(:);

end