function Chapter_7_Figure_7

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This matlab file reproduces simulation studies in the book:
% Systems Biology: Mathematical modeling and model analysis
% by A. Kremling
%
% It is related to Figure 7 in Chapter 7
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% --- parameters

p.limit= 0.9;
R    = [0:.01:p.limit];
p.k0 = 0.4;
p.k1 = 0.01;
p.k2 = 1;
p.k3 = 1;
p.k4 = 0.2;
p.K1 = 0.05;
p.K2 = 0.05;
p.E0 = 1;
op = optimset('Display','off');

% --- calculation

for i=1:length(R)
    p.R=R(i);
    EP(i)=fsolve(@XX2,0.5,op,p);
end
Degradation = p.k2*R;
p.S=0;  Synthesis1=p.k0*EP+p.k1*p.S;
p.S=8;  Synthesis2=p.k0*EP+p.k1*p.S;
p.S=16; Synthesis3=p.k0*EP+p.k1*p.S;

for i=1:length(R)
  p.EP=EP(i);p.R=R(i);
  Sneu(i)=fsolve(@XX3,0,op,p);
end

% --- plotting

subplot(131);
plot(R,EP,'k');
title('Response curve when R is input for the phosporylation of E');
xlabel('R');ylabel('E_P');axis([0 0.9 0 1.01]);

subplot(132);
plot(R,Degradation,'k',R,Synthesis1,'k--',R,Synthesis2,'k--',R,Synthesis3,'k--');axis([0 0.7 0 0.61]);
title('Steady state values in dependence on S ');
xlabel('R');ylabel('rate(dR/dt)');
text(0.6,0.41,'S=0');text(0.6,0.49,'S=8');text(0.6,0.57,'S=16');
text(0.1,0.23,'S \uparrow');
text(0.1,0.55,'Syntheses (dotted)');text(0.4,0.2,'Degradation (solid)');

subplot(133);
plot(Sneu,R,'k');axis([0 15 0 0.6]);
title({'Points of intersection: Depending on the amount of S';'One, two or three solutions can be obtained'});
xlabel('signal S');ylabel('Response R');
text(9.9,0.17,' \downarrow S_B');

end


function x=XX2(EP,p)
x=p.k3*p.R*(p.E0-EP)/(p.K1+p.E0-EP)-p.k4*EP/(p.K2+EP);
end

function y=XX3(Sneu,p)
y=p.k0*p.EP+p.k1*Sneu-p.k2*p.R;
end
