function Chapter_7_Figure_8

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This matlab file reproduces simulation studies in the book:
% Systems Biology: Mathematical modeling and model analysis
% by A. Kremling
%
% It is related to Figure 8 in Chapter 7
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% -------------- figure 7.8: signal-response-curve multistability --- %

% --- parameters
p.k0 = 0.4;
p.k1 = 0.01;
p.k2 = 1;
p.k3 = 1;
p.k4 = 0.2;
p.K1 = 0.05;
p.K2 = 0.05;
p.E0 = 1;

% --- calculation 

% an initial condition is chosen (S=5) such that the lower stable branch is reached (steady state 1). Then, the
% incoming signal is increased (S=20) before returning to its original value (S=5). The
% system remains in steady state 2.

S=5;
[t,V]=ode15s(@lindiff,[0 20],[0 0]);
figure(1);
plot(t,V(:,1),'k')
xlabel('time');
hold on;
xlabel('time'), ylabel('Response R');

V0 = V(end, :);

S=20;
[t,V]=ode15s(@lindiff,[20 40],V0);
plot(t,V(:,1),'k');
hold on;

V0 = V(end, :);

S=5;
[t,V]=ode15s(@lindiff,[40 60],V0);
plot(t,V(:,1),'k');
hold on;

stairs([0 20 40 60],[0.1 0.3 0.1 0.1],'-.k')
text(10,0.04,'steady state 1'), text(50,0.45,'steady state 2')

function [dV]=lindiff(t,V);
    
% V(1)--> R, V(2)--> Ep    
    
dV(1)=p.k0*V(2)+p.k1*S-p.k2.*V(1);
dV(2)=p.k3*V(1).*(p.E0-V(2))/(p.K1+p.E0-V(2))-p.k4.*V(2)./(p.K2+V(2));
dV=dV(:);
end


end

 
