function Chapter_8_Exercise_1

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This matlab file reproduces simulation studies in the book:
% Systems Biology: Mathematical modeling and model analysis
% by A. Kremling
%
% It is related to Exercise 1 in Chapter 8
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Exercise Chapter 8: Analysis of Michaelis - Menten
% kinetics with respect to time hierachries

%  -------- paramters 

k1 = 100;    
km1 = 10; 
k2 = 1.5;
e0 = 1;
qq = 1.4;

tmax = 200;
time = 0:1:tmax;

%  -------- simulation, plots and steady-states

 para = [k1 km1 k2 qq];

 [t,y]=ode15s(@sys_enz,time,[4 e0 0 0],[],para);
 
 figure(1); % FIG 1: plot nonlinear 
 plot(t,y); 
 title('Simulation non linear system') 
 axis([0 200 0 4.2]),
 ylabel('S (black) E (green) ES (red) P (cyan)'), xlabel('t');
 
 % steady state values
 
 s_stat  = y(length(t),1);
 e_stat = y(length(t),2);
 es_stat = y(length(t),3);
 p_stat  =  y(length(t),4);

 stat = [s_stat e_stat es_stat p_stat];
 
%  -------- linear system at steady - state, eigenvectors and eigenvalues
  
jacobi = [-k1*(e0-es_stat)   k1*s_stat+km1 
           k1*(e0-es_stat)  -(k1*s_stat+km1+k2) ];
b_m = [-k1*s_stat 1;k1*s_stat 0];

sys = ss(jacobi,b_m(:,1),[1 0;0 1],[0;0]);    % system with input 1
sys2 =  ss(jacobi,b_m(:,2),[1 0;0 1],[0;0]);  % system with input 2

[eig_vec,eig_wert] = eig(jacobi);

disp('  ')
disp('Values of the time constants')
lambda1 = eig_wert(1,1);
lambda2 = eig_wert(2,2);
disp('1. :'),disp(-1/lambda1);
disp('2. :'),disp(-1/lambda2);

iT = inv(eig_vec);

disp('Matrix T^-1')
disp(iT)


%__________________________________________________________________________________
%  now we disturb the system 
%  -------- small step on E0 for the nonlinear and linear system
%           calculation of the new "modes" z

% -- non linear system

delta_q = 0;
delta_e0 = 0.01;  % step !!

factor = 1/delta_e0;  % is used to scale step response

para = [k1 km1 k2 qq+delta_q];
initial = [0 delta_e0 0 0] +  stat;

% -- non linear system

[time,y2]=ode15s(@sys_enz,time,initial,[],para);

% -- linear system

y2_lin2 = step(sys,time); 

% -------- comparison linear and non-linear system

figure(2); % FIG 2: comparison
plot(time,y2(:,1)-y2(1,1),'b--',time,y2(:,3)-y2(1,3),'r--',time, ...
     y2_lin2(:,1)/factor,'b-',time,y2_lin2(:,2)/factor,'r-') 
title('Comparison linear (solid) and non linear system (dashed) step E0')
ylabel('S (black) ES (red)'),xlabel('t');


%__________________________________________________________________________________
% now we consider a reduced model and compare with the linearized model
%  -------- reduced model
%

u = ones(length(time),1)/factor;
b_star = iT*b_m(:,1);

z2 = -b_star(2)*u/lambda2;   % steady state assumption for fast mode
z1_a = eig_wert(1,1);
z1_b = b_star(1);
sys_z1 = ss(z1_a,z1_b,1,0);  % dynamicsl system slow mode
z1 = step(sys_z1,time)/factor;

y2_red = eig_vec*[z1'      % back transformation
       	       z2'];

figure(3);  % FIG 3: linear systems: comparison
plot(time,y2_lin2(:,1)/factor,'b',time,y2_lin2(:,2)/factor,'r',time,y2_red(1,:),'b--',time,y2_red(2,:),'r--');
title('Comparison linear (solid) and reduced linear system (dashed) step E0')
ylabel('S (black) ES (red)'),xlabel('t');


%____________________________________________________________________________________
%____________________________________________________________________________________
%____________________________________________________________________________________

% non linear model equations

function yp = sys_enz(t,y,para)

k1 = para(1);
km1= para(2);
k2 = para(3);
F  = para(4); 

s = y(1,:);
e = y(2,:);
es = y(3,:);
p = y(4,:); 

yp(1,1) = F - k1*s.*e + km1*es;
yp(2,1) = -k1*s.*e + (km1+k2)*es;
yp(3,1) = k1*s.*e - (km1+k2)*es;
yp(4,1) = k2*es - F;
