function Chapter_8_Figure_3

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This matlab file reproduces simulation studies in the book:
% Systems Biology: Mathematical modeling and model analysis
% by A. Kremling
%
% It is related to Figure 3 in Chapter 8
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% --- parameters: k_1/k_{-1} = 0.1

p.k1 = 10;       
p.k = 1;
y0 = [1;0;1;1;1;1];             % vector of initial conditions
time = 0:0.01:3;

% --- calculation: k_1/k_{-1} = 0.1
options = odeset('RelTol',1e-6,'AbsTol',1e-9,'Vectorized','on');
[t,y] = ode15s(@f,time,y0,options,p);

a = y(:,1);                  % evaluation
b = y(:,2);
z1 = y(:,3);
z2 = y(:,4);
B = y(:,5);
B2 = y(:,6);

% --- plotting: k_1/k_{-1} = 0.1

figure(1); subplot(221)
plot(t,a,t,b,'--');title('Original coordinates k_1/k_{-1} = 0.1')
legend('A','B'), axis([-0.1 max(time) 0 1])
subplot(223), plot(t,z2,t,z1,'--');title('New coordinates k_1/k_{-1} = 0.1')
legend('z2 (A)','z1 (A+B)'), axis([-0.1 max(time) 0 1])

%_______________________________________________________

% --- parameters:  k_1/k_{-1} = 0.01

p.k1 = 100;       
p.k = 1;
y0 = [1;0;1;1;1;1];             % vector of initial conditions
time = 0:0.01:3;

% --- calculation: k_1/k_{-1} = 0.01

options = odeset('RelTol',1e-6,'AbsTol',1e-9,'Vectorized','on');
[t,y] = ode15s(@f,time,y0,options,p);

a = y(:,1);                  % evaluation
b = y(:,2);
z1 = y(:,3);
z2 = y(:,4);
B = y(:,5);
B2 = y(:,6);

% --- plotting:k_1/k_{-1} = 0.01

figure (1), hold on, subplot(222)
plot(t,a,t,b,'--');title('Original coordinates k_1/k_{-1} = 0.01')
legend('A','B'), axis([-0.1 max(time) 0 1])
subplot(224), plot(t,z2,t,z1,'--');title('New coordinates k_1/k_{-1} = 0.01')
legend('z2 (A)','z1 (A+B)'), axis([-0.1 max(time) 0 1])

% ----------------------------------------------------------
% ----------------------------------------------------------

function out = f(t,y,p)

a = y(1,:);
b = y(2,:);
z1 = y(3,:);
z2 = y(4,:);
B = y(5,:);
B2 = y(6,:);

la1 = -(p.k1+2*p.k)/2+0.5*sqrt(p.k1^2+4*p.k^2); %eigenvalues
la2 = -(p.k1+2*p.k)/2-0.5*sqrt(p.k1^2+4*p.k^2);

out =[-p.k1 * a + p.k*b      % original V1
      p.k1 * a - 2*p.k*b     % original V2
      la1*z1                 % transformation Z1
      la2*z2                 % transformation Z2
      -p.k*B*(1+2*p.k/p.k1)
      -p.k*B2];              % reduced modell


