function Chapter_8_Figure_7

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This matlab file reproduces simulation studies in the book:
% Systems Biology: Mathematical modeling and model analysis
% by A. Kremling
%
% It is related to Figure 7 in Chapter 8
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

close all;

% --- Parameters

rmax=2;
K=1;
S=[0:0.1:10];
dz=0.01;

% --- calculation

% --- Basis: Kinetik r = rmax*S/(S+K)

wrK  =-rmax*S./(K+S).^2;        %sensitivity respective K
nwrK =-K./(K+S);                %normed sensitivity
wrr  = S./(K+S);                %sensitivity respective r
nwrr = ones(1,length(nwrK));    %normed sensitivity

% --- Plots of sensitivities

w11=ones(1,length(S));              % sensitivities in W
w12=-K./(K+S);
w21=w12;
w22=K^2./(K+S).^2;


% --- summation over dz
for i=1:length(S)
    W_11(i)=w11(i)*dz;
    W_12(i)=w12(i)*dz;
    W_21(i)=W_12(i);
    W_22(i)=w22(i)*dz;
end

W11=sum(W_11);                     % summation
W12=sum(W_12);
W21=W12;
W22=sum(W_22);

W=[W11 W12;W21 W22];
[eigenvector,eigenvalue]=eig(W);     % EW and EV

v1=eigenvector(:,1);
v2=eigenvector(:,2);                 % corresponds to max. EW

% --- calculation of parameter coming about by deflection 

K_new_min    =K*(1+v1(2));          % assign new parameter
rmax_new_min =rmax*(1+v1(1));
K_new_max    =K*(1+v2(2));
rmax_new_max =rmax*(1+v2(1));


% --- in each case insertion into first equation

r = rmax*S./(K+S);
r_max=rmax_new_max*S./(K_new_max+S);      % Kinetik for max
r_min=rmax_new_min*S./(K_new_min+S);      % Kinetik for min

% --- plotting

figure(1);plot(S,r,'k',S,r_max,'k--',S,r_min,'k-.');
xlabel('Substrat');ylabel('r');
title({'Simulation study with varied parameters values: Note that in any case';...
    'the parameter deviation has to fulfill the constraint Equation (8.81).'});
legend('Orginal','maximal deviation','minimal deviation');

end