function Chapter_9_Exercise_2

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This matlab file reproduces simulation studies in the book:
% Systems Biology: Mathematical modeling and model analysis
% by A. Kremling
%
% It is related to Exercise_2 in Chapter 9
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

close all;

% --- Parameters

Lacex = 0.5:1.0:10;
y0 = [0.01;0.01];   % [Lacin LacY]

n = 0.8;             % stable if: ka*kd>n*kl*k
ka = 3;
k = 2; 
kd = 2;            % kd = 1: unstable ; kd = 2 : stable for var = 2;
kl = 2;
Lu = 1;
Lo = 4;
lim3 = n*(Lo-Lu);

disp('  ')
disp(' Parameters used for the simulation study:')
disp('  ')
disp('ka*kd'),disp(ka*kd),disp('  ')
disp('n'),disp(n),disp('  ')
disp('k*kl'),disp(k*kl),disp('  ')

var  = 2;

% --- Calculation

for ll = 1:length(Lacex);

u = Lacex(ll);
para = [n;ka;k;kd;kl;u;Lu;Lo;lim3];

time = [0:0.05:40];

options = odeset('RelTol',1e-6,'AbsTol',[1e-9],'Vectorized','on');
[t,y] = ode15s(@f,time,y0,options,para,var);

Lacin = y(:,1);
LacY = y(:,2);

stat_Lacin(ll) = Lacin(length(t));  % steady state values for intracellular lactose and LacY
stat_LacY(ll) = LacY(length(t));

y0 = [stat_Lacin(ll) stat_LacY(ll)];

end;

% --- plotting
figure(1);clf;plot(Lacex,stat_LacY,'b');
xlabel('External lactose '), ylabel('LacY');
title('LacY steady state values in dependence of external lactose');


% ----------------------------------------------------------
% ----------------------------------------------------------

function out = f(t,y,para,var)

Lacin = y(1,:);
LacY = y(2,:);

n = para(1);
ka = para(2);
k = para(3); 
kd = para(4);
kl = para(5);
Lacex = para(6);
Lu =  para(7);
Lo = para(8);
lim3 = para(9);

if Lacin < Lu,
  ri = 0;
elseif (Lacin > Lu & Lacin < Lo),
  ri = n*(Lacin-Lu);
else 
  ri = lim3;
end

if var == 2, ri = n*Lacin; end;

out1 = kl*LacY+Lacex-ka*Lacin ; % out1=Lacin/dt
out2 = k*ri-kd*LacY;            % out2=LacY/dt

out = [out1
       out2];



