function Chapter_9_Figure_11

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This matlab file reproduces simulation studies in the book:
% Systems Biology: Mathematical modeling and model analysis
% by A. Kremling
%
% It is related to Figure 11 in Chapter 9
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

close all;

% --- Parameters

p.k1=1;
p.k2=1;
p.k3=1;
p.k4=1;
p.r1=1;             %setpoint
p.rz=0;             %disturbance
tsp=[0:0.1:40];
start=[1 1];


% --- Calculation: Figure 9.11D

[t,x]=ode23s(@integral,tsp,start,[],p);

% --- plotting

c=ones(length(t),1);
figure(1), subplot (121)
plot(t,x(:,2),'b', t,c,'k')
title('Simulation using two different values of r_z utilizing equations (9.41).');
xlabel('time'), ylabel('X')

% --- Calculation: Figure 9.11 E
s=tf('s');             
G1=-s^2*p.k4/(s^2+p.k3*s+p.k1*p.k2); % transfer function of disturbance --> I-D-T2-behaviour
%R=p.k3/s^2;
%P=p.k2/(s^2+p.k4);
%S=1/(1+P*R);

% --- plotting
subplot (122)
h=bodeplot(G1,{0.5 5},'b');grid

setoptions(h,'FreqUnits','Hz','PhaseVisible','off');
title('Course of the amplification of S over the frequency range (Equation (9.39))');

end


% ----------------------------------

function drdt=integral(t,start,p)

if t>0
   p.rz=0.20;   %Disturbance 1
end;

if t>20 
  p.rz=0.70;     %Disturbance 2
end;

ez=start(1);
x=start(2);

dezdt =p.r1-p.k2*x;
dxdt  =p.k3*ez-p.k4*x+p.rz;

drdt=[dezdt dxdt]';
end